@@ -684,23 +684,16 @@ module Loofah
 
       ACCEPTABLE_CSS_KEYWORDS = Set.new([
                                           "!important",
-                                          "aqua",
                                           "auto",
-                                          "black",
                                           "block",
-                                          "blue",
                                           "bold",
                                           "both",
                                           "bottom",
-                                          "brown",
                                           "center",
                                           "collapse",
                                           "dashed",
                                           "dotted",
                                           "double",
-                                          "fuchsia",
-                                          "gray",
-                                          "green",
                                           "groove",
                                           "hidden",
                                           "inherit",
@@ -708,35 +701,196 @@ module Loofah
                                           "inset",
                                           "italic",
                                           "left",
-                                          "lime",
-                                          "maroon",
                                           "medium",
-                                          "navy",
                                           "none",
                                           "normal",
                                           "nowrap",
-                                          "olive",
                                           "outset",
                                           "pointer",
-                                          "purple",
-                                          "red",
                                           "revert",
                                           "ridge",
                                           "right",
                                           "separate",
-                                          "silver",
                                           "solid",
-                                          "teal",
                                           "thick",
                                           "thin",
                                           "top",
                                           "transparent",
                                           "underline",
                                           "unset",
-                                          "white",
-                                          "yellow",
                                         ])
 
+      # https://www.w3.org/TR/css-color-3/#html4
+      ACCEPTABLE_CSS_COLORS = Set.new([
+                                        "aqua",
+                                        "black",
+                                        "blue",
+                                        "fuchsia",
+                                        "gray",
+                                        "green",
+                                        "lime",
+                                        "maroon",
+                                        "navy",
+                                        "olive",
+                                        "purple",
+                                        "red",
+                                        "silver",
+                                        "teal",
+                                        "white",
+                                        "yellow",
+                                      ])
+
+      # https://www.w3.org/TR/css-color-3/#svg-color
+      ACCEPTABLE_CSS_EXTENDED_COLORS = Set.new([
+                                                 "aliceblue",
+                                                 "antiquewhite",
+                                                 "aqua",
+                                                 "aquamarine",
+                                                 "azure",
+                                                 "beige",
+                                                 "bisque",
+                                                 "black",
+                                                 "blanchedalmond",
+                                                 "blue",
+                                                 "blueviolet",
+                                                 "brown",
+                                                 "burlywood",
+                                                 "cadetblue",
+                                                 "chartreuse",
+                                                 "chocolate",
+                                                 "coral",
+                                                 "cornflowerblue",
+                                                 "cornsilk",
+                                                 "crimson",
+                                                 "cyan",
+                                                 "darkblue",
+                                                 "darkcyan",
+                                                 "darkgoldenrod",
+                                                 "darkgray",
+                                                 "darkgreen",
+                                                 "darkgrey",
+                                                 "darkkhaki",
+                                                 "darkmagenta",
+                                                 "darkolivegreen",
+                                                 "darkorange",
+                                                 "darkorchid",
+                                                 "darkred",
+                                                 "darksalmon",
+                                                 "darkseagreen",
+                                                 "darkslateblue",
+                                                 "darkslategray",
+                                                 "darkslategrey",
+                                                 "darkturquoise",
+                                                 "darkviolet",
+                                                 "deeppink",
+                                                 "deepskyblue",
+                                                 "dimgray",
+                                                 "dimgrey",
+                                                 "dodgerblue",
+                                                 "firebrick",
+                                                 "floralwhite",
+                                                 "forestgreen",
+                                                 "fuchsia",
+                                                 "gainsboro",
+                                                 "ghostwhite",
+                                                 "gold",
+                                                 "goldenrod",
+                                                 "gray",
+                                                 "green",
+                                                 "greenyellow",
+                                                 "grey",
+                                                 "honeydew",
+                                                 "hotpink",
+                                                 "indianred",
+                                                 "indigo",
+                                                 "ivory",
+                                                 "khaki",
+                                                 "lavender",
+                                                 "lavenderblush",
+                                                 "lawngreen",
+                                                 "lemonchiffon",
+                                                 "lightblue",
+                                                 "lightcoral",
+                                                 "lightcyan",
+                                                 "lightgoldenrodyellow",
+                                                 "lightgray",
+                                                 "lightgreen",
+                                                 "lightgrey",
+                                                 "lightpink",
+                                                 "lightsalmon",
+                                                 "lightseagreen",
+                                                 "lightskyblue",
+                                                 "lightslategray",
+                                                 "lightslategrey",
+                                                 "lightsteelblue",
+                                                 "lightyellow",
+                                                 "lime",
+                                                 "limegreen",
+                                                 "linen",
+                                                 "magenta",
+                                                 "maroon",
+                                                 "mediumaquamarine",
+                                                 "mediumblue",
+                                                 "mediumorchid",
+                                                 "mediumpurple",
+                                                 "mediumseagreen",
+                                                 "mediumslateblue",
+                                                 "mediumspringgreen",
+                                                 "mediumturquoise",
+                                                 "mediumvioletred",
+                                                 "midnightblue",
+                                                 "mintcream",
+                                                 "mistyrose",
+                                                 "moccasin",
+                                                 "navajowhite",
+                                                 "navy",
+                                                 "oldlace",
+                                                 "olive",
+                                                 "olivedrab",
+                                                 "orange",
+                                                 "orangered",
+                                                 "orchid",
+                                                 "palegoldenrod",
+                                                 "palegreen",
+                                                 "paleturquoise",
+                                                 "palevioletred",
+                                                 "papayawhip",
+                                                 "peachpuff",
+                                                 "peru",
+                                                 "pink",
+                                                 "plum",
+                                                 "powderblue",
+                                                 "purple",
+                                                 "red",
+                                                 "rosybrown",
+                                                 "royalblue",
+                                                 "saddlebrown",
+                                                 "salmon",
+                                                 "sandybrown",
+                                                 "seagreen",
+                                                 "seashell",
+                                                 "sienna",
+                                                 "silver",
+                                                 "skyblue",
+                                                 "slateblue",
+                                                 "slategray",
+                                                 "slategrey",
+                                                 "snow",
+                                                 "springgreen",
+                                                 "steelblue",
+                                                 "tan",
+                                                 "teal",
+                                                 "thistle",
+                                                 "tomato",
+                                                 "turquoise",
+                                                 "violet",
+                                                 "wheat",
+                                                 "white",
+                                                 "whitesmoke",
+                                                 "yellow",
+                                                 "yellowgreen",
+                                               ])
+
       # see https://www.quackit.com/css/functions/
       # omit `url` and `image` from that list
       ACCEPTABLE_CSS_FUNCTIONS = Set.new([
@@ -854,7 +1008,7 @@ module Loofah
       ALLOWED_ELEMENTS = ACCEPTABLE_ELEMENTS + MATHML_ELEMENTS + SVG_ELEMENTS
       ALLOWED_ATTRIBUTES = ACCEPTABLE_ATTRIBUTES + MATHML_ATTRIBUTES + SVG_ATTRIBUTES + ARIA_ATTRIBUTES
       ALLOWED_CSS_PROPERTIES = ACCEPTABLE_CSS_PROPERTIES
-      ALLOWED_CSS_KEYWORDS = ACCEPTABLE_CSS_KEYWORDS
+      ALLOWED_CSS_KEYWORDS = ACCEPTABLE_CSS_KEYWORDS + ACCEPTABLE_CSS_COLORS + ACCEPTABLE_CSS_EXTENDED_COLORS
       ALLOWED_CSS_FUNCTIONS = ACCEPTABLE_CSS_FUNCTIONS
       ALLOWED_SVG_PROPERTIES = ACCEPTABLE_SVG_PROPERTIES
       ALLOWED_PROTOCOLS = ACCEPTABLE_PROTOCOLS
